@@ -16,6 +16,9 @@
 
 from PySide.QtGui import QListView, QMainWindow, QWidget, QVBoxLayout, QLineEdit, QIcon, QScrollArea, QGridLayout, QLabel, QImage, QPixmap, QPushButton, QSortFilterProxyModel
 from PySide.QtCore import QAbstractListModel, Qt, Signal, SIGNAL
+from PySide.QtMaemo5 import QMaemo5InformationBox
+
+
 from custom_widgets import UberSquareWindow, Title
 from threads import UserDetailsThread, UserMayorships
 from venues import VenueListWindow
@@ -46,7 +49,7 @@ class UserProfile(QWidget):
         # FIXME: this may fail!
         location = user['user']['checkins']['items'][0]['venue']['name']
         lastSeen = user['user']['checkins']['items'][0]['createdAt']
-        lastSeen = datetime.fromtimestamp(lastSeen).strftime("%Y-%m-%d %X")
+        lastSeen = datetime.fromtimestamp(lastSeen).strftime("%d %b, %H:%M")
         location = "Last seen at <b>" +  location + "</b>, at <i>" + lastSeen + "</i>"
 
         description = description + "<br>" + location
@@ -117,10 +120,10 @@ class UserDetailsWindow(UberSquareWindow):
             self.connect(checkinButton, SIGNAL("clicked()"), self.checkin)
             gridLayout.addWidget(checkinButton, i, 1)
 
-        if user['user']['relationship'] == "friend":
-            i += 1
-            #gridLayout.addWidget(QPushButton("Unfriend"), i, 0, 1, 2)
-            gridLayout.addWidget(QLabel("TODO: Unfriend"), i, 0, 1, 2)
+        # TODO!
+        #if user['user']['relationship'] == "friend":
+        #    i += 1
+        #    gridLayout.addWidget(QLabel("TODO: Unfriend"), i, 0, 1, 2)
         elif user['user']['relationship'] == "self":
             i += 1
             gridLayout.addWidget(QLabel("It's you!"), i, 0, 1, 2)
@@ -144,9 +147,11 @@ class UserDetailsWindow(UberSquareWindow):
         else:
             gridLayout.addWidget(QLabel("No mayorships"), i, 0)
         i += 1
-        gridLayout.addWidget(QPushButton("TODO: See places " + firstName + " has been to."), i, 0, 1, 2)
 
-        i += 1
+        # TODO!
+        #gridLayout.addWidget(QPushButton("TODO: See places " + firstName + " has been to."), i, 0, 1, 2)
+        #i += 1
+
         update_user_button = QPushButton("Refresh user details")
         update_user_button.setIcon(QIcon.fromTheme("general_refresh"))
         self.connect(update_user_button, SIGNAL("clicked()"), self.__update)
@@ -175,11 +180,11 @@ class UserDetailsWindow(UberSquareWindow):
 
         c = CheckinConfirmation(self, venue)
         c.exec_()
-        if c.buttonRole(c.clickedButton()) == CheckinConfirmation.YesRole:
+        if c.result() == QDialog.Accepted:
             try:
                 # TODO: do this in a separate thread
                 ll = LocationProvider().get_ll(venue)
-                response = foursquare.checkin(venue, ll, self.shoutText.text())
+                response = foursquare.checkin(venue, ll, self.shoutText.text(), c.broadcast())
                 CheckinDetails(self, response).show()
             except IOError:
                 self.networkError.emit()
@@ -302,6 +307,8 @@ class UserListWindow(UberSquareWindow):
         self.setUsers(self.parent().users())
         if not self.shown:
             self.show()
+        else:
+            QMaemo5InformationBox.information(self, "Leaderboard updated")
 
     def filter(self, text):
         self.list.filter(text)
